@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,13 +11,13 @@ func AlgoliaApiKey() *config.Rule {
 	r := config.Rule{
 		Description: "Identified an Algolia API Key, which could result in unauthorized search operations and data exposure on Algolia-managed platforms.",
 		RuleID:      "algolia-api-key",
-		Regex:       generateSemiGenericRegex([]string{"algolia"}, `[a-z0-9]{32}`, true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"algolia"}, `[a-z0-9]{32}`, true),
 		Keywords:    []string{"algolia"},
 	}
 
 	// validate
 	tps := []string{
-		"algolia_key := " + secrets.NewSecret(hex("32")),
+		"algolia_key := " + secrets.NewSecret(utils.Hex("32")),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
