@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func MattermostAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "mattermost-access-token",
 		Description: "Identified a Mattermost Access Token, which may compromise team communication channels and data privacy.",
-		Regex:       generateSemiGenericRegex([]string{"mattermost"}, alphaNumeric("26"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"mattermost"}, utils.AlphaNumeric("26"), true),
 
 		Keywords: []string{
 			"mattermost",
@@ -19,7 +20,7 @@ func MattermostAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("mattermost", secrets.NewSecret(alphaNumeric("26"))),
+		utils.GenerateSampleSecret("mattermost", secrets.NewSecret(utils.AlphaNumeric("26"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
