@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"regexp"
 
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
@@ -13,7 +14,7 @@ func SumoLogicAccessID() *config.Rule {
 		RuleID:      "sumologic-access-id",
 		Description: "Discovered a SumoLogic Access ID, potentially compromising log management services and data analytics integrity.",
 		// TODO: Make 'su' case-sensitive.
-		Regex: generateSemiGenericRegex([]string{"sumo"},
+		Regex: utils.GenerateSemiGenericRegex([]string{"sumo"},
 			"su[a-zA-Z0-9]{12}", false),
 
 		Entropy: 3,
@@ -34,7 +35,7 @@ func SumoLogicAccessID() *config.Rule {
 		`sumologic_access_id = "sug5XpdpaoxtOH"`,     // gitleaks:allow
 		`export SUMOLOGIC_ACCESSID="suDbJw97o9WVo0"`, // gitleaks:allow
 		`SUMO_ACCESS_ID = "suGyI5imvADdvU"`,          // gitleaks:allow
-		generateSampleSecret("sumo", "su"+secrets.NewSecret(alphaNumeric("12"))),
+		utils.GenerateSampleSecret("sumo", "su"+secrets.NewSecret(utils.AlphaNumeric("12"))),
 	}
 	fps := []string{
 		`- (NSNumber *)sumOfProperty:(NSString *)property;`,
@@ -47,7 +48,7 @@ func SumoLogicAccessID() *config.Rule {
 		`SUMOLOGIC_ACCESSID: ${SUMOLOGIC_ACCESSID}`,
 		`export SUMOLOGIC_ACCESSID=XXXXXXXXXXXXXX`, // gitleaks:allow
 	}
-	return validate(r, tps, fps)
+	return utils.Validate(r, tps, fps)
 }
 
 func SumoLogicAccessToken() *config.Rule {
@@ -55,8 +56,8 @@ func SumoLogicAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "sumologic-access-token",
 		Description: "Uncovered a SumoLogic Access Token, which could lead to unauthorized access to log data and analytics insights.",
-		Regex: generateSemiGenericRegex([]string{"sumo"},
-			alphaNumeric("64"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"sumo"},
+			utils.AlphaNumeric("64"), true),
 
 		Entropy: 3,
 		Keywords: []string{
@@ -70,7 +71,7 @@ func SumoLogicAccessToken() *config.Rule {
 		`SUMO_ACCESS_KEY: gxq3rJQkS6qovOg9UY2Q70iH1jFZx0WBrrsiAYv4XHodogAwTKyLzvFK4neRN8Dk`,             // gitleaks:allow
 		`SUMOLOGIC_ACCESSKEY: 9RITWb3I3kAnSyUolcVJq4gwM17JRnQK8ugRaixFfxkdSl8ys17ZtEL3LotESKB7`,         // gitleaks:allow
 		`sumo_access_key = "3Kof2VffNQ0QgYIhXUPJosVlCaQKm2hfpWE6F1fT9YGY74blQBIPsrkCcf1TwKE5"`,          // gitleaks:allow
-		generateSampleSecret("sumo", secrets.NewSecret(alphaNumeric("64"))),
+		utils.GenerateSampleSecret("sumo", secrets.NewSecret(utils.AlphaNumeric("64"))),
 	}
 	fps := []string{
 		`#   SUMO_ACCESS_KEY=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx`, // gitleaks:allow
@@ -80,5 +81,5 @@ func SumoLogicAccessToken() *config.Rule {
 		`sumo_access_key   = "<SUMOLOGIC ACCESS KEY>"`,
 		`SUMO_ACCESS_KEY: AbCeFG123`,
 	}
-	return validate(r, tps, fps)
+	return utils.Validate(r, tps, fps)
 }
