@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func TwitchAPIToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "twitch-api-token",
 		Description: "Discovered a Twitch API token, which could compromise streaming services and account integrations.",
-		Regex:       generateSemiGenericRegex([]string{"twitch"}, alphaNumeric("30"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"twitch"}, utils.AlphaNumeric("30"), true),
 		Keywords: []string{
 			"twitch",
 		},
@@ -18,7 +19,7 @@ func TwitchAPIToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("twitch", secrets.NewSecret(alphaNumeric("30"))),
+		utils.GenerateSampleSecret("twitch", secrets.NewSecret(utils.AlphaNumeric("30"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
