@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func Typeform() *config.Rule {
 	r := config.Rule{
 		RuleID:      "typeform-api-token",
 		Description: "Uncovered a Typeform API token, which could lead to unauthorized survey management and data collection.",
-		Regex: generateSemiGenericRegex([]string{"typeform"},
+		Regex: utils.GenerateSemiGenericRegex([]string{"typeform"},
 			`tfp_[a-z0-9\-_\.=]{59}`, true),
 		Keywords: []string{
 			"tfp_",
@@ -19,7 +20,7 @@ func Typeform() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("typeformAPIToken", "tfp_"+secrets.NewSecret(alphaNumericExtended("59"))),
+		utils.GenerateSampleSecret("typeformAPIToken", "tfp_"+secrets.NewSecret(utils.AlphaNumericExtended("59"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
