@@ -2,7 +2,6 @@ package config
 
 import (
 	_ "embed"
-	"fmt"
 	"regexp"
 	"sort"
 	"strings"
@@ -116,8 +115,8 @@ func (vc *ViperConfig) Translate() (Config, error) {
 			configPathRegex = regexp.MustCompile(r.Path)
 		}
 		r := Rule{
-			Description: r.Description,
 			RuleID:      r.ID,
+			Description: r.Description,
 			Regex:       configRegex,
 			Path:        configPathRegex,
 			SecretGroup: r.SecretGroup,
@@ -132,11 +131,11 @@ func (vc *ViperConfig) Translate() (Config, error) {
 				StopWords:   r.Allowlist.StopWords,
 			},
 		}
-		orderedRules = append(orderedRules, r.RuleID)
-
-		if r.Regex != nil && r.SecretGroup > r.Regex.NumSubexp() {
-			return Config{}, fmt.Errorf("%s invalid regex secret group %d, max regex secret group %d", r.Description, r.SecretGroup, r.Regex.NumSubexp())
+		if err := r.Validate(); err != nil {
+			return Config{}, err
 		}
+
+		orderedRules = append(orderedRules, r.RuleID)
 		rulesMap[r.RuleID] = r
 	}
 	var allowlistRegexes []*regexp.Regexp
